multidim.PointCloud.make_pers0 — GDA Toolbox v1.0 Manual

# multidim.PointCloud.make_pers0

`PointCloud.` `make_pers0`(cutoff=-1.0)

  Run the UnionFind algorithm to mark connected components of the SimplicialComplex. This marks points as positive/negative. It also marks the reprensetatives of points. It makes a PersDiag object with unionfind, saved as `self.pers0`

#### Previous topic

multidim.PointCloud.gaussian_fit

#### Next topic

multidim.PointCloud.make_pers1_rca1